% Cedrat Actuator
%   :PROPERTIES:
%   :header-args:matlab+: :tangle ../src/initializeCedratPiezo.m
%   :header-args:matlab+: :comments org :mkdirp yes
%   :header-args:matlab+: :eval no :results none
%   :END:
%   <<sec:initializeCedratPiezo>>

% This Matlab function is accessible [[file:../src/initializeCedratPiezo.m][here]].


function [cedrat] = initializeCedratPiezo(opts_param)
  %% Default values for opts
  opts = struct();

  %% Populate opts with input parameters
  if exist('opts_param','var')
      for opt = fieldnames(opts_param)'
          opts.(opt{1}) = opts_param.(opt{1});
      end
  end

  %% Stewart Object
  cedrat = struct();
  cedrat.k = 10e7; % Linear Stiffness of each "blade" [N/m]
  cedrat.ka = 10e7; % Linear Stiffness of the stack [N/m]

  cedrat.c = 0.1*sqrt(1*cedrat.k); % [N/(m/s)]
  cedrat.ca = 0.1*sqrt(1*cedrat.ka); % [N/(m/s)]

  cedrat.L = 80; % Total Width of the Actuator[mm]
  cedrat.H = 45; % Total Height of the Actuator [mm]
  cedrat.L2 = sqrt((cedrat.L/2)^2 + (cedrat.H/2)^2); % Length of the elipsoidal sections [mm]
  cedrat.alpha = 180/pi*atan2(cedrat.L/2, cedrat.H/2); % [deg]

  %% Save
  save('./mat/stages.mat', 'cedrat', '-append');
end
